@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
 __title__ = 'qjson'
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 __author__ = 'Jerry Chou'
 __license__ = 'MIT License'
 
-import qjson
\ No newline at end of file
+from .qjson import loads
\ No newline at end of file
